--- old/usr/src/lib/libm/common/R/sinf.c	2019-06-06 20:39:25.368689386 +0000
+++ new/usr/src/lib/libm/common/R/sinf.c	2019-06-06 20:39:25.387771287 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,6 +38,7 @@
 
 extern const int _TBL_ipio2_inf[];
 extern int __rem_pio2m(double *, double *, int, int, int, const int *);
+
 #if defined(__i386) && !defined(__amd64)
 extern int __swapRP(int);
 #endif
@@ -56,26 +59,26 @@
 	6.077100506506192601475e-11,	/* 2^-34  * 1.0B4611A626331 */
 };
 
-#define	S0	C[0]
-#define	S1	C[1]
-#define	S2	C[2]
-#define	S3	C[3]
-#define	C0	C[4]
-#define	C1	C[5]
-#define	C2	C[6]
-#define	C3	C[7]
-#define	C4	C[8]
-#define	invpio2	C[9]
-#define	half	C[10]
-#define	pio2_1  C[11]
-#define	pio2_t	C[12]
+#define	S0		C[0]
+#define	S1		C[1]
+#define	S2		C[2]
+#define	S3		C[3]
+#define	C0		C[4]
+#define	C1		C[5]
+#define	C2		C[6]
+#define	C3		C[7]
+#define	C4		C[8]
+#define	invpio2		C[9]
+#define	half		C[10]
+#define	pio2_1		C[11]
+#define	pio2_t		C[12]
 
 float
 sinf(float x)
 {
-	double	y, z, w;
-	float	f;
-	int	n, ix, hx, hy;
+	double y, z, w;
+	float f;
+	int n, ix, hx, hy;
 	volatile int i __unused;
 
 	hx = *((int *)&x);
@@ -83,7 +86,7 @@
 
 	y = (double)x;
 
-	if (ix <= 0x4016cbe4) {		/* |x| < 3*pi/4 */
+	if (ix <= 0x4016cbe4) {			/* |x| < 3*pi/4 */
 		if (ix <= 0x3f490fdb) {		/* |x| < pi/4 */
 			if (ix <= 0x39800000) {	/* |x| <= 2**-12 */
 				i = (int)y;
@@ -92,31 +95,34 @@
 #endif
 				return (x);
 			}
+
 			z = y * y;
-			return ((float)((y * (S0 + z * S1)) *
-			    (S2 + z * (S3 + z))));
+			return ((float)((y * (S0 + z * S1)) * (S2 + z *
+			    (S3 + z))));
 		} else if (hx > 0) {
 			y = (y - pio2_1) - pio2_t;
 			z = y * y;
-			return ((float)(((C0 + z * C1) + (z * z) * C2) *
-			    (C3 + z * (C4 + z))));
+			return ((float)(((C0 + z * C1) + (z * z) * C2) * (C3 +
+			    z * (C4 + z))));
 		} else {
 			y = (y + pio2_1) + pio2_t;
 			z = y * y;
-			return ((float)-(((C0 + z * C1) + (z * z) * C2) *
-			    (C3 + z * (C4 + z))));
+			return ((float)-(((C0 + z * C1) + (z * z) * C2) * (C3 +
+			    z * (C4 + z))));
 		}
 	} else if (ix <= 0x49c90fdb) {	/* |x| < 2^19*pi */
 #if defined(__i386) && !defined(__amd64)
-		int	rp;
+		int rp;
 
 		rp = __swapRP(fp_extended);
 #endif
 		w = y * invpio2;
+
 		if (hx < 0)
 			n = (int)(w - half);
 		else
 			n = (int)(w + half);
+
 		y = (y - n * pio2_1) - n * pio2_t;
 #if defined(__i386) && !defined(__amd64)
 		if (rp != fp_extended)
@@ -124,12 +130,14 @@
 #endif
 	} else {
 		if (ix >= 0x7f800000)
-			return (x / x);	/* sin(Inf or NaN) is NaN */
+			return (x / x);		/* sin(Inf or NaN) is NaN */
+
 		hy = ((int *)&y)[HIWORD];
 		n = ((hy >> 20) & 0x7ff) - 1046;
 		((int *)&w)[HIWORD] = (hy & 0xfffff) | 0x41600000;
 		((int *)&w)[LOWORD] = ((int *)&y)[LOWORD];
 		n = __rem_pio2m(&w, &y, n, 1, 0, _TBL_ipio2_inf);
+
 		if (hy < 0) {
 			y = -y;
 			n = -n;
@@ -139,13 +147,13 @@
 	if (n & 1) {
 		/* compute cos y */
 		z = y * y;
-		f = (float)(((C0 + z * C1) + (z * z) * C2) *
-		    (C3 + z * (C4 + z)));
+		f = (float)(((C0 + z * C1) + (z * z) * C2) * (C3 + z * (C4 +
+		    z)));
 	} else {
 		/* compute sin y */
 		z = y * y;
 		f = (float)((y * (S0 + z * S1)) * (S2 + z * (S3 + z)));
 	}
 
-	return ((n & 2)? -f : f);
+	return ((n & 2) ? -f : f);
 }
